@@ -25,6 +25,8 @@ gboolean greeter_item_ulist_setup (void);
 void greeter_item_ulist_enable (void);
 void greeter_item_ulist_disable (void);
 void greeter_item_ulist_set_user (const char *user);
+gchar * greeter_item_ulist_get_selected_user (void);
 void greeter_item_ulist_unset_selected_user (void);
+void greeter_item_ulist_select_user (gchar *login);
 
 #endif
